@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import logging
 from pathlib import Path
+from typing import Generator, List, Set, Union
 
 import numpy as np
 from apscheduler.executors.pool import ThreadPoolExecutor
@@ -60,6 +61,17 @@ class CardLiveDataManager:
             logger.exception(e)
         logger.debug('Finished updating CARD:Live data.')
 
+    def data_archive_generator(self, file_names: Union[List[str], Set[str]] = None) -> Generator[bytes, None, None]:
+        """
+        Get the CARD:Live JSON files as a zipstream generator.
+        :param file_names: The file names to load into the archive.
+        :return: A generator which allows streaming of the zip file contents.
+        """
+        if file_names is None:
+            file_names = self.card_data.files()
+
+        return self._data_loader.data_archive_generator(file_names)
+
     @property
     def card_data(self) -> CardLiveData:
         return self._card_live_data
